==> create-es6-js-0.0.1.tgz: package/brunch-config.js <==
// See http://brunch.io for documentation.
module.exports = {
  paths: {
    public: 'dist',
    watched: ['src'],
  },
  conventions: {
    ignored: ['docs'],
  },
  sourceMaps: true,
  bower: {
    enabled: false,
  },
  npm: {
    globals: {
      createjs: 'createjs-browserify',
    },
  },
  files: {
    javascripts: {
      joinTo: {
        'create-es6.js': [
          /^src/,
          (path) => {
            return !path.includes('/docs');
          },
        ],
      },
      order: {
        before: [
          // 'node_modules/jquery/dist/jquery.js'
        ]
      },
    },
  },
  plugins: {
    eslint: {
      pattern: /^src\/.*\.js?$/,
      warnOnly: true,
      config: {
        rules: {
          'array-callback-return': 'warn'
        }
      }
    },
    babel: {
      presets: ['es2015'],
    },
    uglify: {
      mangle: true,
      minimize: true,
      sourceMap: true,
      compress: {
        warnings: false,
        screw_ie8: true,
        conditionals: true,
        unused: true,
        comparisons: true,
        sequences: true,
        dead_code: true,
        evaluate: true,
        if_return: true,
        join_vars: true,
        global_defs: {
          DEBUG: false,
        }
      },
      output: {
        comments: false,
      },
    },
    order: [
      'eslint-brunch',
      'babel-brunch',
      'uglify-js-brunch',
    ],
  },
  modules: {
    nameCleaner: path => path.replace(/^src\//, ''),
    autoRequire: {
      'scripts/app.js': ['scripts/app']
    }
  },
};

==> create-es6-js-0.0.2.tgz: package/brunch-config.js <==
// See http://brunch.io for documentation.
module.exports = {
  paths: {
    public: 'dist',
    watched: ['src'],
  },
  conventions: {
    ignored: ['docs'],
  },
  sourceMaps: true,
  bower: {
    enabled: false,
  },
  npm: {
    globals: {
      createjs: 'createjs-browserify',
    },
  },
  files: {
    javascripts: {
      joinTo: {
        'create-es6.js': [
          /^src/,
          (path) => {
            return !path.includes('/docs');
          },
        ],
      },
      order: {
        before: [
          // 'node_modules/jquery/dist/jquery.js'
        ]
      },
    },
  },
  plugins: {
    eslint: {
      pattern: /^src\/.*\.js?$/,
      warnOnly: true,
      config: {
        rules: {
          'array-callback-return': 'warn'
        }
      }
    },
    babel: {
      presets: ['es2015'],
    },
    uglify: {
      mangle: true,
      minimize: true,
      sourceMap: true,
      compress: {
        warnings: false,
        screw_ie8: true,
        conditionals: true,
        unused: true,
        comparisons: true,
        sequences: true,
        dead_code: true,
        evaluate: true,
        if_return: true,
        join_vars: true,
        global_defs: {
          DEBUG: false,
        }
      },
      output: {
        comments: false,
      },
    },
    order: [
      'eslint-brunch',
      'babel-brunch',
      'uglify-js-brunch',
    ],
  },
  modules: {
    nameCleaner: path => path.replace(/^src\//, 'create-es6-js/').replace(/\/index.js$/, ''),
    autoRequire: {
      'scripts/app.js': ['scripts/app']
    }
  },
};
